@@ -25,6 +25,7 @@ class AIRClient:
         self._config = AIRClientConfig(
             client=client,
             data_set_id=schedule_asset.data_set_id,
+            schedule_asset=schedule_asset,
             schedule_asset_id=schedule_asset.id,
             schedule_asset_ext_id=sa_ext_id,
             data_fields=parse_json_if_json(schedule_asset.metadata.get(SA_FIELD_META_DATA)) or {},
@@ -44,6 +45,7 @@ class AIRClient:
             print(
                 f"Tenant: {client.config.project}\nSchedule asset ext. ID: {self._config.schedule_asset_ext_id}\n"
                 f"Model name: {self._config.model_name}\nModel version: {self._config.model_version}\n"
+                f"Backfilling in progress: {self.backfilling.in_progress}\n"
             )
 
     @property
@@ -81,7 +83,7 @@ class AIRClient:
 
         return_fields = []
         for id, field in zip(field_names, fields):
-            field_type = self._config.data_fields_defs[id]["type"]
+            field_type = self._config.data_fields_defs[id]["python-type"]
             ret_val = parse_json_if_json(field)
             if isinstance(ret_val, list):  # this means multiple=True
                 return_fields.append(list(map(field_type, ret_val)))
@@ -103,11 +105,11 @@ class AIRClient:
             "TimeSeries": str,
             "Asset": str,
         }
-        dct["type"] = legal_types[dct["type"]]
+        dct["python-type"] = legal_types[dct["type"]]
         return dct
 
-    def create_data_field_dct(self, json_str: Optional[str]):
-        lst_of_field_defs = parse_json_if_json(json_str) or []
+    def create_data_field_dct(self, json: Optional[str]):
+        lst_of_field_defs = parse_json_if_json(json) or []
         return {dct.pop("id"): self.convert_type_info(dct) for dct in lst_of_field_defs}
 
     @staticmethod
@@ -139,5 +141,5 @@ class AIRClient:
         if len(backfill_asset_list) == 1:
             return backfill_asset_list[0]
         raise AIRClientError(
-            f"Found {len(backfill_asset_list)} backfilling assets. Expected exactly 1 backfilling asset"
+            f"Found {len(backfill_asset_list)} backfilling asset(s). Expected exactly 1 backfilling asset"
         )
